# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: plugin.proto
"""Generated protocol buffer code."""
from robomotion import struct_pb2 as struct__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='plugin.proto',
    package='proto',
    syntax='proto3',
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0cplugin.proto\x12\x05proto\x1a\x0cstruct.proto\"2\n\x05\x45rror\x12\n\n\x02OK\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"1\n\x0bInitRequest\x12\x14\n\x0c\x65vent_server\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\"/\n\x0fOnCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c\"/\n\x10OnCreateResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"3\n\x10OnMessageRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x11\n\tinMessage\x18\x02 \x01(\x0c\"D\n\x11OnMessageResponse\x12\x12\n\noutMessage\x18\x01 \x01(\x0c\x12\x1b\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0c.proto.Error\"\x1e\n\x0eOnCloseRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\".\n\x0fOnCloseResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"\x07\n\x05\x45mpty\";\n\x0c\x44\x65\x62ugRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"2\n\x14\x45mitFlowEventRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"?\n\x11\x45mitOutputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\x05\"?\n\x10\x45mitErrorRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x13GetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\"=\n\x14GetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\'\n\x08Variable\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"7\n\x12GetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\"=\n\x13GetVariableResponse\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"_\n\x12SetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\x12&\n\x05value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct2\xe7\x01\n\x04Node\x12(\n\x04Init\x12\x12.proto.InitRequest\x1a\x0c.proto.Empty\x12;\n\x08OnCreate\x12\x16.proto.OnCreateRequest\x1a\x17.proto.OnCreateResponse\x12>\n\tOnMessage\x12\x17.proto.OnMessageRequest\x1a\x18.proto.OnMessageResponse\x12\x38\n\x07OnClose\x12\x15.proto.OnCloseRequest\x1a\x16.proto.OnCloseResponse2\xcd\x03\n\rRuntimeHelper\x12#\n\x05\x43lose\x12\x0c.proto.Empty\x1a\x0c.proto.Empty\x12*\n\x05\x44\x65\x62ug\x12\x13.proto.DebugRequest\x1a\x0c.proto.Empty\x12:\n\rEmitFlowEvent\x12\x1b.proto.EmitFlowEventRequest\x1a\x0c.proto.Empty\x12\x34\n\nEmitOutput\x12\x18.proto.EmitOutputRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitError\x12\x17.proto.EmitErrorRequest\x1a\x0c.proto.Empty\x12G\n\x0cGetVaultItem\x12\x1a.proto.GetVaultItemRequest\x1a\x1b.proto.GetVaultItemResponse\x12\x44\n\x0bGetVariable\x12\x19.proto.GetVariableRequest\x1a\x1a.proto.GetVariableResponse\x12\x36\n\x0bSetVariable\x12\x19.proto.SetVariableRequest\x1a\x0c.proto.Emptyb\x06proto3',
    dependencies=[struct__pb2.DESCRIPTOR, ])


_ERROR = _descriptor.Descriptor(
    name='Error',
    full_name='proto.Error',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='OK', full_name='proto.Error.OK', index=0,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='code', full_name='proto.Error.code', index=1,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='proto.Error.message', index=2,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=87,
)


_INITREQUEST = _descriptor.Descriptor(
    name='InitRequest',
    full_name='proto.InitRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='event_server', full_name='proto.InitRequest.event_server', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='port', full_name='proto.InitRequest.port', index=1,
            number=2, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=89,
    serialized_end=138,
)


_ONCREATEREQUEST = _descriptor.Descriptor(
    name='OnCreateRequest',
    full_name='proto.OnCreateRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.OnCreateRequest.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='config', full_name='proto.OnCreateRequest.config', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=140,
    serialized_end=187,
)


_ONCREATERESPONSE = _descriptor.Descriptor(
    name='OnCreateResponse',
    full_name='proto.OnCreateResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='error', full_name='proto.OnCreateResponse.error', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=189,
    serialized_end=236,
)


_ONMESSAGEREQUEST = _descriptor.Descriptor(
    name='OnMessageRequest',
    full_name='proto.OnMessageRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.OnMessageRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='inMessage', full_name='proto.OnMessageRequest.inMessage', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=238,
    serialized_end=289,
)


_ONMESSAGERESPONSE = _descriptor.Descriptor(
    name='OnMessageResponse',
    full_name='proto.OnMessageResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='outMessage', full_name='proto.OnMessageResponse.outMessage', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='error', full_name='proto.OnMessageResponse.error', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=291,
    serialized_end=359,
)


_ONCLOSEREQUEST = _descriptor.Descriptor(
    name='OnCloseRequest',
    full_name='proto.OnCloseRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.OnCloseRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=361,
    serialized_end=391,
)


_ONCLOSERESPONSE = _descriptor.Descriptor(
    name='OnCloseResponse',
    full_name='proto.OnCloseResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='error', full_name='proto.OnCloseResponse.error', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=393,
    serialized_end=439,
)


_EMPTY = _descriptor.Descriptor(
    name='Empty',
    full_name='proto.Empty',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=441,
    serialized_end=448,
)


_DEBUGREQUEST = _descriptor.Descriptor(
    name='DebugRequest',
    full_name='proto.DebugRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.DebugRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.DebugRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='proto.DebugRequest.message', index=2,
            number=3, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=450,
    serialized_end=509,
)


_EMITFLOWEVENTREQUEST = _descriptor.Descriptor(
    name='EmitFlowEventRequest',
    full_name='proto.EmitFlowEventRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.EmitFlowEventRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.EmitFlowEventRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=511,
    serialized_end=561,
)


_EMITOUTPUTREQUEST = _descriptor.Descriptor(
    name='EmitOutputRequest',
    full_name='proto.EmitOutputRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.EmitOutputRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='output', full_name='proto.EmitOutputRequest.output', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='port', full_name='proto.EmitOutputRequest.port', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=563,
    serialized_end=626,
)


_EMITERRORREQUEST = _descriptor.Descriptor(
    name='EmitErrorRequest',
    full_name='proto.EmitErrorRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.EmitErrorRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.EmitErrorRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='proto.EmitErrorRequest.message', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=628,
    serialized_end=691,
)


_GETVAULTITEMREQUEST = _descriptor.Descriptor(
    name='GetVaultItemRequest',
    full_name='proto.GetVaultItemRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='vaultId', full_name='proto.GetVaultItemRequest.vaultId', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='ItemId', full_name='proto.GetVaultItemRequest.ItemId', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=693,
    serialized_end=747,
)


_GETVAULTITEMRESPONSE = _descriptor.Descriptor(
    name='GetVaultItemResponse',
    full_name='proto.GetVaultItemResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='item', full_name='proto.GetVaultItemResponse.item', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=749,
    serialized_end=810,
)


_VARIABLE = _descriptor.Descriptor(
    name='Variable',
    full_name='proto.Variable',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='scope', full_name='proto.Variable.scope', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.Variable.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=812,
    serialized_end=851,
)


_GETVARIABLEREQUEST = _descriptor.Descriptor(
    name='GetVariableRequest',
    full_name='proto.GetVariableRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='variable', full_name='proto.GetVariableRequest.variable', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=853,
    serialized_end=908,
)


_GETVARIABLERESPONSE = _descriptor.Descriptor(
    name='GetVariableResponse',
    full_name='proto.GetVariableResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='value', full_name='proto.GetVariableResponse.value', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=910,
    serialized_end=971,
)


_SETVARIABLEREQUEST = _descriptor.Descriptor(
    name='SetVariableRequest',
    full_name='proto.SetVariableRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='variable', full_name='proto.SetVariableRequest.variable', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='value', full_name='proto.SetVariableRequest.value', index=1,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=973,
    serialized_end=1068,
)

_ONCREATERESPONSE.fields_by_name['error'].message_type = _ERROR
_ONMESSAGERESPONSE.fields_by_name['error'].message_type = _ERROR
_ONCLOSERESPONSE.fields_by_name['error'].message_type = _ERROR
_GETVAULTITEMRESPONSE.fields_by_name['item'].message_type = struct__pb2._STRUCT
_GETVARIABLEREQUEST.fields_by_name['variable'].message_type = _VARIABLE
_GETVARIABLERESPONSE.fields_by_name['value'].message_type = struct__pb2._STRUCT
_SETVARIABLEREQUEST.fields_by_name['variable'].message_type = _VARIABLE
_SETVARIABLEREQUEST.fields_by_name['value'].message_type = struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['InitRequest'] = _INITREQUEST
DESCRIPTOR.message_types_by_name['OnCreateRequest'] = _ONCREATEREQUEST
DESCRIPTOR.message_types_by_name['OnCreateResponse'] = _ONCREATERESPONSE
DESCRIPTOR.message_types_by_name['OnMessageRequest'] = _ONMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['OnMessageResponse'] = _ONMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['OnCloseRequest'] = _ONCLOSEREQUEST
DESCRIPTOR.message_types_by_name['OnCloseResponse'] = _ONCLOSERESPONSE
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['DebugRequest'] = _DEBUGREQUEST
DESCRIPTOR.message_types_by_name['EmitFlowEventRequest'] = _EMITFLOWEVENTREQUEST
DESCRIPTOR.message_types_by_name['EmitOutputRequest'] = _EMITOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['EmitErrorRequest'] = _EMITERRORREQUEST
DESCRIPTOR.message_types_by_name['GetVaultItemRequest'] = _GETVAULTITEMREQUEST
DESCRIPTOR.message_types_by_name['GetVaultItemResponse'] = _GETVAULTITEMRESPONSE
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['GetVariableRequest'] = _GETVARIABLEREQUEST
DESCRIPTOR.message_types_by_name['GetVariableResponse'] = _GETVARIABLERESPONSE
DESCRIPTOR.message_types_by_name['SetVariableRequest'] = _SETVARIABLEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR': _ERROR,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.Error)
})
_sym_db.RegisterMessage(Error)

InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
    'DESCRIPTOR': _INITREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.InitRequest)
})
_sym_db.RegisterMessage(InitRequest)

OnCreateRequest = _reflection.GeneratedProtocolMessageType('OnCreateRequest', (_message.Message,), {
    'DESCRIPTOR': _ONCREATEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCreateRequest)
})
_sym_db.RegisterMessage(OnCreateRequest)

OnCreateResponse = _reflection.GeneratedProtocolMessageType('OnCreateResponse', (_message.Message,), {
    'DESCRIPTOR': _ONCREATERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCreateResponse)
})
_sym_db.RegisterMessage(OnCreateResponse)

OnMessageRequest = _reflection.GeneratedProtocolMessageType('OnMessageRequest', (_message.Message,), {
    'DESCRIPTOR': _ONMESSAGEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnMessageRequest)
})
_sym_db.RegisterMessage(OnMessageRequest)

OnMessageResponse = _reflection.GeneratedProtocolMessageType('OnMessageResponse', (_message.Message,), {
    'DESCRIPTOR': _ONMESSAGERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnMessageResponse)
})
_sym_db.RegisterMessage(OnMessageResponse)

OnCloseRequest = _reflection.GeneratedProtocolMessageType('OnCloseRequest', (_message.Message,), {
    'DESCRIPTOR': _ONCLOSEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCloseRequest)
})
_sym_db.RegisterMessage(OnCloseRequest)

OnCloseResponse = _reflection.GeneratedProtocolMessageType('OnCloseResponse', (_message.Message,), {
    'DESCRIPTOR': _ONCLOSERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCloseResponse)
})
_sym_db.RegisterMessage(OnCloseResponse)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR': _EMPTY,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.Empty)
})
_sym_db.RegisterMessage(Empty)

DebugRequest = _reflection.GeneratedProtocolMessageType('DebugRequest', (_message.Message,), {
    'DESCRIPTOR': _DEBUGREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.DebugRequest)
})
_sym_db.RegisterMessage(DebugRequest)

EmitFlowEventRequest = _reflection.GeneratedProtocolMessageType('EmitFlowEventRequest', (_message.Message,), {
    'DESCRIPTOR': _EMITFLOWEVENTREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.EmitFlowEventRequest)
})
_sym_db.RegisterMessage(EmitFlowEventRequest)

EmitOutputRequest = _reflection.GeneratedProtocolMessageType('EmitOutputRequest', (_message.Message,), {
    'DESCRIPTOR': _EMITOUTPUTREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.EmitOutputRequest)
})
_sym_db.RegisterMessage(EmitOutputRequest)

EmitErrorRequest = _reflection.GeneratedProtocolMessageType('EmitErrorRequest', (_message.Message,), {
    'DESCRIPTOR': _EMITERRORREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.EmitErrorRequest)
})
_sym_db.RegisterMessage(EmitErrorRequest)

GetVaultItemRequest = _reflection.GeneratedProtocolMessageType('GetVaultItemRequest', (_message.Message,), {
    'DESCRIPTOR': _GETVAULTITEMREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVaultItemRequest)
})
_sym_db.RegisterMessage(GetVaultItemRequest)

GetVaultItemResponse = _reflection.GeneratedProtocolMessageType('GetVaultItemResponse', (_message.Message,), {
    'DESCRIPTOR': _GETVAULTITEMRESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVaultItemResponse)
})
_sym_db.RegisterMessage(GetVaultItemResponse)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
    'DESCRIPTOR': _VARIABLE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.Variable)
})
_sym_db.RegisterMessage(Variable)

GetVariableRequest = _reflection.GeneratedProtocolMessageType('GetVariableRequest', (_message.Message,), {
    'DESCRIPTOR': _GETVARIABLEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVariableRequest)
})
_sym_db.RegisterMessage(GetVariableRequest)

GetVariableResponse = _reflection.GeneratedProtocolMessageType('GetVariableResponse', (_message.Message,), {
    'DESCRIPTOR': _GETVARIABLERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVariableResponse)
})
_sym_db.RegisterMessage(GetVariableResponse)

SetVariableRequest = _reflection.GeneratedProtocolMessageType('SetVariableRequest', (_message.Message,), {
    'DESCRIPTOR': _SETVARIABLEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.SetVariableRequest)
})
_sym_db.RegisterMessage(SetVariableRequest)


_NODE = _descriptor.ServiceDescriptor(
    name='Node',
    full_name='proto.Node',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1071,
    serialized_end=1302,
    methods=[
        _descriptor.MethodDescriptor(
            name='Init',
            full_name='proto.Node.Init',
            index=0,
            containing_service=None,
            input_type=_INITREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='OnCreate',
            full_name='proto.Node.OnCreate',
            index=1,
            containing_service=None,
            input_type=_ONCREATEREQUEST,
            output_type=_ONCREATERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='OnMessage',
            full_name='proto.Node.OnMessage',
            index=2,
            containing_service=None,
            input_type=_ONMESSAGEREQUEST,
            output_type=_ONMESSAGERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='OnClose',
            full_name='proto.Node.OnClose',
            index=3,
            containing_service=None,
            input_type=_ONCLOSEREQUEST,
            output_type=_ONCLOSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_NODE)

DESCRIPTOR.services_by_name['Node'] = _NODE


_RUNTIMEHELPER = _descriptor.ServiceDescriptor(
    name='RuntimeHelper',
    full_name='proto.RuntimeHelper',
    file=DESCRIPTOR,
    index=1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1305,
    serialized_end=1766,
    methods=[
        _descriptor.MethodDescriptor(
            name='Close',
            full_name='proto.RuntimeHelper.Close',
            index=0,
            containing_service=None,
            input_type=_EMPTY,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='Debug',
            full_name='proto.RuntimeHelper.Debug',
            index=1,
            containing_service=None,
            input_type=_DEBUGREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='EmitFlowEvent',
            full_name='proto.RuntimeHelper.EmitFlowEvent',
            index=2,
            containing_service=None,
            input_type=_EMITFLOWEVENTREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='EmitOutput',
            full_name='proto.RuntimeHelper.EmitOutput',
            index=3,
            containing_service=None,
            input_type=_EMITOUTPUTREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='EmitError',
            full_name='proto.RuntimeHelper.EmitError',
            index=4,
            containing_service=None,
            input_type=_EMITERRORREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetVaultItem',
            full_name='proto.RuntimeHelper.GetVaultItem',
            index=5,
            containing_service=None,
            input_type=_GETVAULTITEMREQUEST,
            output_type=_GETVAULTITEMRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetVariable',
            full_name='proto.RuntimeHelper.GetVariable',
            index=6,
            containing_service=None,
            input_type=_GETVARIABLEREQUEST,
            output_type=_GETVARIABLERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='SetVariable',
            full_name='proto.RuntimeHelper.SetVariable',
            index=7,
            containing_service=None,
            input_type=_SETVARIABLEREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_RUNTIMEHELPER)

DESCRIPTOR.services_by_name['RuntimeHelper'] = _RUNTIMEHELPER

# @@protoc_insertion_point(module_scope)



import json
from jsonpath_ng import jsonpath, parse


class Context:
    def get_id(self) -> str:
        pass

    def set(self, key: str, value: object):
        pass

    def get(self, key: str) -> object:
        pass

    def get_raw(self) -> bytes:
        pass


class Message(Context):
    def __init__(self, data: bytes):
        msg = json.loads(data.decode('utf-8'))
        self.id = msg['id']
        self.data = data

    def get_id(self) -> str:
        return str(self.id)

    def set(self, key: str, value: object):
        msg = json.loads(self.data.decode('utf-8'))
        msg[key] = value
        self.data = json.dumps(msg).encode('utf-8')

    def get(self, key: str) -> object:
        msg = json.loads(self.data.decode('utf-8'))
        val = parse('$.%s' % key).find(msg)
        if len(val) == 0:
            return None

        return val[0].value

    def get_raw(self) -> bytes:
        return self.data



from cmath import isnan
from distutils.log import debug
from enum import Enum
from select import select
import grpc
from json import dumps, loads
import os
from psutil import net_connections, process_iter
from psutil._common import CONN_LISTEN
from robomotion.utils import File
from robomotion import runner_pb2, runner_pb2_grpc


class AttachConfig:
    def __init__(self, protocol: str, addr: str, pid: int, namespace: str):
        self.protocol = protocol
        self.addr = addr
        self.pid = pid
        self.namespace = namespace


class EProtocol(Enum):
    ProtocolInvalid = ''
    ProtocolNetRPC = 'netrpc'
    ProtocolGRPC = 'grpc'


class Debug:
    atteched_to: str = ''

    @staticmethod
    def attach(g_addr: str, ns: str):
        cfg = AttachConfig(str(EProtocol.ProtocolGRPC.value),
                           g_addr, os.getpid(), ns)
        cfg_data = dumps(cfg.__dict__)

        Debug.atteched_to = Debug.get_rpc_addr()
        if Debug.atteched_to == '':
            print('empty gRPC address')
            exit(0)

        print('Attached to %s' % Debug.atteched_to)

        channel = grpc.insecure_channel(Debug.atteched_to)
        client = runner_pb2_grpc.DebugStub(channel)

        request = runner_pb2.AttachRequest(config=cfg_data.encode())
        client.Attach(request)
        channel.close()

    @staticmethod
    def detach(ns: str):
        if Debug.atteched_to == '':
            print('empty gRPC address')
            exit(0)

        channel = grpc.insecure_channel(Debug.atteched_to)
        client = runner_pb2_grpc.DebugStub(channel)

        request = runner_pb2.DetachRequest(namespace=ns)
        client.Detach(request)
        channel.close()

    @staticmethod
    def get_rpc_addr() -> str:
        tabs = Debug.get_netstat_ports(CONN_LISTEN, 'robomotion-runner')

        if len(tabs) == 0:
            return ""
        elif len(tabs) == 1:
            return '%s:%d' % (tabs[0].laddr.ip, tabs[0].laddr.port)

        return Debug.select_tab(tabs)

    @staticmethod
    def get_netstat_ports(state: str = CONN_LISTEN, process_name: str = ''):
        tabs = net_connections()

        pids = []
        for proc in process_iter():
            if process_name.lower() in proc.name().lower():
                pids.append(proc.pid)

        filtered = filter(lambda tab: tab.status ==
                          state and tab.pid in pids, tabs)
        return list(filtered)

    @staticmethod
    def select_tab(tabs: []) -> str:
        count = len(tabs)

        c = 0
        robots = ""
        for i in range(0, count):
            addr = '%s:%d' % (tabs[i].laddr.ip, tabs[i].laddr.port)
            name = Debug.get_robot_name(addr)
            if name == '':
                continue

            c += 1
            robots += '%d) %s\n' % (c, name)

        selected = 0
        print('Found %d robots running on the machine:' % c)
        print('%s' % robots)
        print('Please select a robot to attach (1-%d):' % c)

        while True:
            line = input()
            if not line.isnumeric():
                continue

            selected = int(line)
            if selected > 0 and selected <= count:
                tab = tabs[selected-1]
                return '%s:%d' % (tab.laddr.ip, tab.laddr.port)

    @staticmethod
    def get_robot_name(addr: str) -> str:
        try:
            channel = grpc.insecure_channel(addr)
            client = runner_pb2_grpc.RunnerStub(channel)

            request = runner_pb2.Null()
            resp = client.RobotName(request)
            channel.close()
            return resp.robot_name
        except:
            return ''



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from robomotion import plugin_pb2 as plugin__pb2


class NodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
            '/proto.Node/Init',
            request_serializer=plugin__pb2.InitRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.OnCreate = channel.unary_unary(
            '/proto.Node/OnCreate',
            request_serializer=plugin__pb2.OnCreateRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnCreateResponse.FromString,
        )
        self.OnMessage = channel.unary_unary(
            '/proto.Node/OnMessage',
            request_serializer=plugin__pb2.OnMessageRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnMessageResponse.FromString,
        )
        self.OnClose = channel.unary_unary(
            '/proto.Node/OnClose',
            request_serializer=plugin__pb2.OnCloseRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnCloseResponse.FromString,
        )


class NodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnClose(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Init': grpc.unary_unary_rpc_method_handler(
            servicer.Init,
            request_deserializer=plugin__pb2.InitRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'OnCreate': grpc.unary_unary_rpc_method_handler(
            servicer.OnCreate,
            request_deserializer=plugin__pb2.OnCreateRequest.FromString,
            response_serializer=plugin__pb2.OnCreateResponse.SerializeToString,
        ),
        'OnMessage': grpc.unary_unary_rpc_method_handler(
            servicer.OnMessage,
            request_deserializer=plugin__pb2.OnMessageRequest.FromString,
            response_serializer=plugin__pb2.OnMessageResponse.SerializeToString,
        ),
        'OnClose': grpc.unary_unary_rpc_method_handler(
            servicer.OnClose,
            request_deserializer=plugin__pb2.OnCloseRequest.FromString,
            response_serializer=plugin__pb2.OnCloseResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.Node', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class Node(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(request,
             target,
             options=(),
             channel_credentials=None,
             call_credentials=None,
             insecure=False,
             compression=None,
             wait_for_ready=None,
             timeout=None,
             metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/Init',
                                             plugin__pb2.InitRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnCreate(request,
                 target,
                 options=(),
                 channel_credentials=None,
                 call_credentials=None,
                 insecure=False,
                 compression=None,
                 wait_for_ready=None,
                 timeout=None,
                 metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/OnCreate',
                                             plugin__pb2.OnCreateRequest.SerializeToString,
                                             plugin__pb2.OnCreateResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnMessage(request,
                  target,
                  options=(),
                  channel_credentials=None,
                  call_credentials=None,
                  insecure=False,
                  compression=None,
                  wait_for_ready=None,
                  timeout=None,
                  metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/OnMessage',
                                             plugin__pb2.OnMessageRequest.SerializeToString,
                                             plugin__pb2.OnMessageResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnClose(request,
                target,
                options=(),
                channel_credentials=None,
                call_credentials=None,
                insecure=False,
                compression=None,
                wait_for_ready=None,
                timeout=None,
                metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/OnClose',
                                             plugin__pb2.OnCloseRequest.SerializeToString,
                                             plugin__pb2.OnCloseResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class RuntimeHelperStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Close = channel.unary_unary(
            '/proto.RuntimeHelper/Close',
            request_serializer=plugin__pb2.Empty.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.Debug = channel.unary_unary(
            '/proto.RuntimeHelper/Debug',
            request_serializer=plugin__pb2.DebugRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitFlowEvent = channel.unary_unary(
            '/proto.RuntimeHelper/EmitFlowEvent',
            request_serializer=plugin__pb2.EmitFlowEventRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitOutput = channel.unary_unary(
            '/proto.RuntimeHelper/EmitOutput',
            request_serializer=plugin__pb2.EmitOutputRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitError = channel.unary_unary(
            '/proto.RuntimeHelper/EmitError',
            request_serializer=plugin__pb2.EmitErrorRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.GetVaultItem = channel.unary_unary(
            '/proto.RuntimeHelper/GetVaultItem',
            request_serializer=plugin__pb2.GetVaultItemRequest.SerializeToString,
            response_deserializer=plugin__pb2.GetVaultItemResponse.FromString,
        )
        self.GetVariable = channel.unary_unary(
            '/proto.RuntimeHelper/GetVariable',
            request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
            response_deserializer=plugin__pb2.GetVariableResponse.FromString,
        )
        self.SetVariable = channel.unary_unary(
            '/proto.RuntimeHelper/SetVariable',
            request_serializer=plugin__pb2.SetVariableRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )


class RuntimeHelperServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Debug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitFlowEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVaultItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RuntimeHelperServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Close': grpc.unary_unary_rpc_method_handler(
            servicer.Close,
            request_deserializer=plugin__pb2.Empty.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'Debug': grpc.unary_unary_rpc_method_handler(
            servicer.Debug,
            request_deserializer=plugin__pb2.DebugRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'EmitFlowEvent': grpc.unary_unary_rpc_method_handler(
            servicer.EmitFlowEvent,
            request_deserializer=plugin__pb2.EmitFlowEventRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'EmitOutput': grpc.unary_unary_rpc_method_handler(
            servicer.EmitOutput,
            request_deserializer=plugin__pb2.EmitOutputRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'EmitError': grpc.unary_unary_rpc_method_handler(
            servicer.EmitError,
            request_deserializer=plugin__pb2.EmitErrorRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'GetVaultItem': grpc.unary_unary_rpc_method_handler(
            servicer.GetVaultItem,
            request_deserializer=plugin__pb2.GetVaultItemRequest.FromString,
            response_serializer=plugin__pb2.GetVaultItemResponse.SerializeToString,
        ),
        'GetVariable': grpc.unary_unary_rpc_method_handler(
            servicer.GetVariable,
            request_deserializer=plugin__pb2.GetVariableRequest.FromString,
            response_serializer=plugin__pb2.GetVariableResponse.SerializeToString,
        ),
        'SetVariable': grpc.unary_unary_rpc_method_handler(
            servicer.SetVariable,
            request_deserializer=plugin__pb2.SetVariableRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.RuntimeHelper', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class RuntimeHelper(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Close(request,
              target,
              options=(),
              channel_credentials=None,
              call_credentials=None,
              insecure=False,
              compression=None,
              wait_for_ready=None,
              timeout=None,
              metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/Close',
                                             plugin__pb2.Empty.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Debug(request,
              target,
              options=(),
              channel_credentials=None,
              call_credentials=None,
              insecure=False,
              compression=None,
              wait_for_ready=None,
              timeout=None,
              metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/Debug',
                                             plugin__pb2.DebugRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EmitFlowEvent(request,
                      target,
                      options=(),
                      channel_credentials=None,
                      call_credentials=None,
                      insecure=False,
                      compression=None,
                      wait_for_ready=None,
                      timeout=None,
                      metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/EmitFlowEvent',
                                             plugin__pb2.EmitFlowEventRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EmitOutput(request,
                   target,
                   options=(),
                   channel_credentials=None,
                   call_credentials=None,
                   insecure=False,
                   compression=None,
                   wait_for_ready=None,
                   timeout=None,
                   metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/EmitOutput',
                                             plugin__pb2.EmitOutputRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EmitError(request,
                  target,
                  options=(),
                  channel_credentials=None,
                  call_credentials=None,
                  insecure=False,
                  compression=None,
                  wait_for_ready=None,
                  timeout=None,
                  metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/EmitError',
                                             plugin__pb2.EmitErrorRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVaultItem(request,
                     target,
                     options=(),
                     channel_credentials=None,
                     call_credentials=None,
                     insecure=False,
                     compression=None,
                     wait_for_ready=None,
                     timeout=None,
                     metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/GetVaultItem',
                                             plugin__pb2.GetVaultItemRequest.SerializeToString,
                                             plugin__pb2.GetVaultItemResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVariable(request,
                    target,
                    options=(),
                    channel_credentials=None,
                    call_credentials=None,
                    insecure=False,
                    compression=None,
                    wait_for_ready=None,
                    timeout=None,
                    metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/GetVariable',
                                             plugin__pb2.GetVariableRequest.SerializeToString,
                                             plugin__pb2.GetVariableResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetVariable(request,
                    target,
                    options=(),
                    channel_credentials=None,
                    call_credentials=None,
                    insecure=False,
                    compression=None,
                    wait_for_ready=None,
                    timeout=None,
                    metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/SetVariable',
                                             plugin__pb2.SetVariableRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from robomotion import runner_pb2 as runner__pb2


class RunnerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
            '/proto.Runner/Init',
            request_serializer=runner__pb2.InitRunnerRequest.SerializeToString,
            response_deserializer=runner__pb2.Null.FromString,
        )
        self.Run = channel.unary_unary(
            '/proto.Runner/Run',
            request_serializer=runner__pb2.RunRequest.SerializeToString,
            response_deserializer=runner__pb2.Null.FromString,
        )
        self.Clear = channel.unary_unary(
            '/proto.Runner/Clear',
            request_serializer=runner__pb2.Null.SerializeToString,
            response_deserializer=runner__pb2.Null.FromString,
        )
        self.RobotName = channel.unary_unary(
            '/proto.Runner/RobotName',
            request_serializer=runner__pb2.Null.SerializeToString,
            response_deserializer=runner__pb2.RobotNameResponse.FromString,
        )


class RunnerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Run(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clear(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RobotName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunnerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Init': grpc.unary_unary_rpc_method_handler(
            servicer.Init,
            request_deserializer=runner__pb2.InitRunnerRequest.FromString,
            response_serializer=runner__pb2.Null.SerializeToString,
        ),
        'Run': grpc.unary_unary_rpc_method_handler(
            servicer.Run,
            request_deserializer=runner__pb2.RunRequest.FromString,
            response_serializer=runner__pb2.Null.SerializeToString,
        ),
        'Clear': grpc.unary_unary_rpc_method_handler(
            servicer.Clear,
            request_deserializer=runner__pb2.Null.FromString,
            response_serializer=runner__pb2.Null.SerializeToString,
        ),
        'RobotName': grpc.unary_unary_rpc_method_handler(
            servicer.RobotName,
            request_deserializer=runner__pb2.Null.FromString,
            response_serializer=runner__pb2.RobotNameResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.Runner', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class Runner(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(request,
             target,
             options=(),
             channel_credentials=None,
             call_credentials=None,
             insecure=False,
             compression=None,
             wait_for_ready=None,
             timeout=None,
             metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Runner/Init',
                                             runner__pb2.InitRunnerRequest.SerializeToString,
                                             runner__pb2.Null.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Run(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Runner/Run',
                                             runner__pb2.RunRequest.SerializeToString,
                                             runner__pb2.Null.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clear(request,
              target,
              options=(),
              channel_credentials=None,
              call_credentials=None,
              insecure=False,
              compression=None,
              wait_for_ready=None,
              timeout=None,
              metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Runner/Clear',
                                             runner__pb2.Null.SerializeToString,
                                             runner__pb2.Null.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RobotName(request,
                  target,
                  options=(),
                  channel_credentials=None,
                  call_credentials=None,
                  insecure=False,
                  compression=None,
                  wait_for_ready=None,
                  timeout=None,
                  metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Runner/RobotName',
                                             runner__pb2.Null.SerializeToString,
                                             runner__pb2.RobotNameResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class RobotHelperStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """


class RobotHelperServicer(object):
    """Missing associated documentation comment in .proto file."""


def add_RobotHelperServicer_to_server(servicer, server):
    rpc_method_handlers = {
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.RobotHelper', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class RobotHelper(object):
    """Missing associated documentation comment in .proto file."""


class DebugStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Attach = channel.unary_unary(
            '/proto.Debug/Attach',
            request_serializer=runner__pb2.AttachRequest.SerializeToString,
            response_deserializer=runner__pb2.Nil.FromString,
        )
        self.Detach = channel.unary_unary(
            '/proto.Debug/Detach',
            request_serializer=runner__pb2.DetachRequest.SerializeToString,
            response_deserializer=runner__pb2.Nil.FromString,
        )


class DebugServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Attach(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Detach(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DebugServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Attach': grpc.unary_unary_rpc_method_handler(
            servicer.Attach,
            request_deserializer=runner__pb2.AttachRequest.FromString,
            response_serializer=runner__pb2.Nil.SerializeToString,
        ),
        'Detach': grpc.unary_unary_rpc_method_handler(
            servicer.Detach,
            request_deserializer=runner__pb2.DetachRequest.FromString,
            response_serializer=runner__pb2.Nil.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.Debug', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class Debug(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Attach(request,
               target,
               options=(),
               channel_credentials=None,
               call_credentials=None,
               insecure=False,
               compression=None,
               wait_for_ready=None,
               timeout=None,
               metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Debug/Attach',
                                             runner__pb2.AttachRequest.SerializeToString,
                                             runner__pb2.Nil.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Detach(request,
               target,
               options=(),
               channel_credentials=None,
               call_credentials=None,
               insecure=False,
               compression=None,
               wait_for_ready=None,
               timeout=None,
               metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Debug/Detach',
                                             runner__pb2.DetachRequest.SerializeToString,
                                             runner__pb2.Nil.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc
import gzip
import json
import enum
import threading
from google.protobuf import json_format
from robomotion import plugin_pb2
from robomotion.plugin_pb2_grpc import RuntimeHelperStub
from robomotion.struct_pb2 import Struct
from robomotion.message import Context

from types import SimpleNamespace as Namespace


class Runtime:
    active_nodes = 0
    client: RuntimeHelperStub = None
    event: threading.Event = threading.Event()
    factories = {}
    nodes = {}

    @staticmethod
    def set_client(client: RuntimeHelperStub):
        Runtime.client = client

    @staticmethod
    def check_runner_conn(connection: grpc.Channel):
        def cb(state: grpc.ChannelConnectivity):
            if state == grpc.ChannelConnectivity.TRANSIENT_FAILURE or state == grpc.ChannelConnectivity.SHUTDOWN:
                Runtime.event.set()

        connection.subscribe(cb, True)

    @staticmethod
    def create_node(name: str, factory):
        Runtime.factories[name] = factory

    @staticmethod
    def add_node(guid: str, node):
        Runtime.nodes[guid] = node

    @staticmethod
    def compress(data: bytes):
        return gzip.compress(data)

    @staticmethod
    def decompress(data: bytes):
        return gzip.decompress(data)

    @staticmethod
    def deserialize(data: bytes, c):
        node = c()
        obj = json.loads(data)
        for key in obj.keys():
            if key in node.__dict__.keys():
                if type(obj[key]) is dict:
                    node.__dict__[key] = type(node.__dict__[key])(**obj[key])
                else:
                    node.__dict__[key] = obj[key]

        return node

    @staticmethod
    def close():
        if Runtime.client is None:
            return

        request = plugin_pb2.Empty()
        Runtime.client.Close(request)

    @staticmethod
    def get_variable(variable, ctx: Context):
        scope = variable.scope
        name = variable.name

        if scope == 'Custom':
            return name

        if scope == 'Message':
            return ctx.get(name)

        if Runtime.client is None:
            return None

        var = plugin_pb2.Variable(scope=scope, name=name)
        request = plugin_pb2.GetVariableRequest(variable=var)
        response = Runtime.client.GetVariable(request)

        return json_format.MessageToDict(response.value)['value']

    @staticmethod
    def set_variable(variable, ctx: Context, value: object):
        scope = variable.scope
        name = variable.name

        if scope == 'Message':
            ctx.set(name, value)
            return

        if Runtime.client is None:
            return

        val = Struct()
        val.update({'value': value})

        var = plugin_pb2.Variable(scope=scope, name=name)
        request = plugin_pb2.SetVariableRequest(variable=var, value=val)
        Runtime.client.SetVariable(request)

    @staticmethod
    def get_vault_item(cred):
        if Runtime.client is None:
            return {}

        request = plugin_pb2.GetVaultItemRequest(
            vaultId=cred.vaultId, ItemId=cred.itemId)
        response = Runtime.client.GetVaultItem(request)
        return json_format.MessageToDict(response.item)['value']

    class _DefVal:
        def __init__(self, default: object):
            self.default = default

        def __init__(self, scope: str, name: str):
            self.default = {scope: scope, name: name}

    class _Enum:
        def __init__(self, enums: [], enumNames: []):
            self.__enums = enums
            self.__enumNames = enumNames

        @property
        def enums(self):
            return self.__enums

        @property
        def enumNames(self):
            return self.__enumNames



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: runner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='runner.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'Z(robomotion/robomotion-runner/robot/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0crunner.proto\x12\x05proto\"\x06\n\x04Null\"n\n\x11InitRunnerRequest\x12\x0e\n\x06\x61piUrl\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x14\n\x0crobot_server\x18\x03 \x01(\r\x12\x10\n\x08natsPort\x18\x04 \x01(\r\x12\x12\n\nrobot_name\x18\x05 \x01(\t\"T\n\nRunRequest\x12\x0e\n\x06repoid\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\'\n\x11RobotNameResponse\x12\x12\n\nrobot_name\x18\x01 \x01(\t\"\x05\n\x03Nil\"\x1f\n\rAttachRequest\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\x0c\"\"\n\rDetachRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t2\xb5\x01\n\x06Runner\x12-\n\x04Init\x12\x18.proto.InitRunnerRequest\x1a\x0b.proto.Null\x12%\n\x03Run\x12\x11.proto.RunRequest\x1a\x0b.proto.Null\x12!\n\x05\x43lear\x12\x0b.proto.Null\x1a\x0b.proto.Null\x12\x32\n\tRobotName\x12\x0b.proto.Null\x1a\x18.proto.RobotNameResponse2\r\n\x0bRobotHelper2_\n\x05\x44\x65\x62ug\x12*\n\x06\x41ttach\x12\x14.proto.AttachRequest\x1a\n.proto.Nil\x12*\n\x06\x44\x65tach\x12\x14.proto.DetachRequest\x1a\n.proto.NilB*Z(robomotion/robomotion-runner/robot/protob\x06proto3'
)




_NULL = _descriptor.Descriptor(
  name='Null',
  full_name='proto.Null',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23,
  serialized_end=29,
)


_INITRUNNERREQUEST = _descriptor.Descriptor(
  name='InitRunnerRequest',
  full_name='proto.InitRunnerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apiUrl', full_name='proto.InitRunnerRequest.apiUrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.InitRunnerRequest.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_server', full_name='proto.InitRunnerRequest.robot_server', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='natsPort', full_name='proto.InitRunnerRequest.natsPort', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_name', full_name='proto.InitRunnerRequest.robot_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=141,
)


_RUNREQUEST = _descriptor.Descriptor(
  name='RunRequest',
  full_name='proto.RunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repoid', full_name='proto.RunRequest.repoid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository', full_name='proto.RunRequest.repository', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='proto.RunRequest.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='proto.RunRequest.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=227,
)


_ROBOTNAMERESPONSE = _descriptor.Descriptor(
  name='RobotNameResponse',
  full_name='proto.RobotNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot_name', full_name='proto.RobotNameResponse.robot_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=268,
)


_NIL = _descriptor.Descriptor(
  name='Nil',
  full_name='proto.Nil',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=275,
)


_ATTACHREQUEST = _descriptor.Descriptor(
  name='AttachRequest',
  full_name='proto.AttachRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='proto.AttachRequest.config', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=308,
)


_DETACHREQUEST = _descriptor.Descriptor(
  name='DetachRequest',
  full_name='proto.DetachRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='proto.DetachRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=344,
)

DESCRIPTOR.message_types_by_name['Null'] = _NULL
DESCRIPTOR.message_types_by_name['InitRunnerRequest'] = _INITRUNNERREQUEST
DESCRIPTOR.message_types_by_name['RunRequest'] = _RUNREQUEST
DESCRIPTOR.message_types_by_name['RobotNameResponse'] = _ROBOTNAMERESPONSE
DESCRIPTOR.message_types_by_name['Nil'] = _NIL
DESCRIPTOR.message_types_by_name['AttachRequest'] = _ATTACHREQUEST
DESCRIPTOR.message_types_by_name['DetachRequest'] = _DETACHREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Null = _reflection.GeneratedProtocolMessageType('Null', (_message.Message,), {
  'DESCRIPTOR' : _NULL,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.Null)
  })
_sym_db.RegisterMessage(Null)

InitRunnerRequest = _reflection.GeneratedProtocolMessageType('InitRunnerRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITRUNNERREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.InitRunnerRequest)
  })
_sym_db.RegisterMessage(InitRunnerRequest)

RunRequest = _reflection.GeneratedProtocolMessageType('RunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.RunRequest)
  })
_sym_db.RegisterMessage(RunRequest)

RobotNameResponse = _reflection.GeneratedProtocolMessageType('RobotNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTNAMERESPONSE,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.RobotNameResponse)
  })
_sym_db.RegisterMessage(RobotNameResponse)

Nil = _reflection.GeneratedProtocolMessageType('Nil', (_message.Message,), {
  'DESCRIPTOR' : _NIL,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.Nil)
  })
_sym_db.RegisterMessage(Nil)

AttachRequest = _reflection.GeneratedProtocolMessageType('AttachRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.AttachRequest)
  })
_sym_db.RegisterMessage(AttachRequest)

DetachRequest = _reflection.GeneratedProtocolMessageType('DetachRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETACHREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.DetachRequest)
  })
_sym_db.RegisterMessage(DetachRequest)


DESCRIPTOR._options = None

_RUNNER = _descriptor.ServiceDescriptor(
  name='Runner',
  full_name='proto.Runner',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=347,
  serialized_end=528,
  methods=[
  _descriptor.MethodDescriptor(
    name='Init',
    full_name='proto.Runner.Init',
    index=0,
    containing_service=None,
    input_type=_INITRUNNERREQUEST,
    output_type=_NULL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Run',
    full_name='proto.Runner.Run',
    index=1,
    containing_service=None,
    input_type=_RUNREQUEST,
    output_type=_NULL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Clear',
    full_name='proto.Runner.Clear',
    index=2,
    containing_service=None,
    input_type=_NULL,
    output_type=_NULL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RobotName',
    full_name='proto.Runner.RobotName',
    index=3,
    containing_service=None,
    input_type=_NULL,
    output_type=_ROBOTNAMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNNER)

DESCRIPTOR.services_by_name['Runner'] = _RUNNER


_ROBOTHELPER = _descriptor.ServiceDescriptor(
  name='RobotHelper',
  full_name='proto.RobotHelper',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=530,
  serialized_end=543,
  methods=[
])
_sym_db.RegisterServiceDescriptor(_ROBOTHELPER)

DESCRIPTOR.services_by_name['RobotHelper'] = _ROBOTHELPER


_DEBUG = _descriptor.ServiceDescriptor(
  name='Debug',
  full_name='proto.Debug',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=545,
  serialized_end=640,
  methods=[
  _descriptor.MethodDescriptor(
    name='Attach',
    full_name='proto.Debug.Attach',
    index=0,
    containing_service=None,
    input_type=_ATTACHREQUEST,
    output_type=_NIL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Detach',
    full_name='proto.Debug.Detach',
    index=1,
    containing_service=None,
    input_type=_DETACHREQUEST,
    output_type=_NIL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEBUG)

DESCRIPTOR.services_by_name['Debug'] = _DEBUG

# @@protoc_insertion_point(module_scope)
